#ifndef NT2_INCLUDE_FUNCTIONS_PROD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PROD_HPP_INCLUDED

#include <nt2/reduction/include/functions/prod.hpp>

#endif
